==> zio-aws-ssoadmin_3-5.17.153.1-sources.jar: zio/aws/ssoadmin/model/DescribePermissionSetProvisioningStatusResponse.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DescribePermissionSetProvisioningStatusResponse(
    permissionSetProvisioningStatus: Option[
      zio.aws.ssoadmin.model.PermissionSetProvisioningStatus
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse = {
    import DescribePermissionSetProvisioningStatusResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse
      .builder()
      .optionallyWith(
        permissionSetProvisioningStatus.map(value => value.buildAwsValue())
      )(_.permissionSetProvisioningStatus)
      .build()
  }
  def asReadOnly
      : zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse.ReadOnly =
    zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse
      .wrap(buildAwsValue())
}
object DescribePermissionSetProvisioningStatusResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse =
      zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse(
        permissionSetProvisioningStatus.map(value => value.asEditable)
      )
    def permissionSetProvisioningStatus: Option[
      zio.aws.ssoadmin.model.PermissionSetProvisioningStatus.ReadOnly
    ]
    def getPermissionSetProvisioningStatus: ZIO[
      Any,
      AwsError,
      zio.aws.ssoadmin.model.PermissionSetProvisioningStatus.ReadOnly
    ] = AwsError.unwrapOptionField(
      "permissionSetProvisioningStatus",
      permissionSetProvisioningStatus
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse
  ) extends zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse.ReadOnly {
    override val permissionSetProvisioningStatus: Option[
      zio.aws.ssoadmin.model.PermissionSetProvisioningStatus.ReadOnly
    ] = scala
      .Option(impl.permissionSetProvisioningStatus())
      .map(value =>
        zio.aws.ssoadmin.model.PermissionSetProvisioningStatus.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse
  ): zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ssoadmin_3-5.19.31.1-sources.jar: zio/aws/ssoadmin/model/DescribePermissionSetProvisioningStatusResponse.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DescribePermissionSetProvisioningStatusResponse(
    permissionSetProvisioningStatus: Optional[
      zio.aws.ssoadmin.model.PermissionSetProvisioningStatus
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse = {
    import DescribePermissionSetProvisioningStatusResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse
      .builder()
      .optionallyWith(
        permissionSetProvisioningStatus.map(value => value.buildAwsValue())
      )(_.permissionSetProvisioningStatus)
      .build()
  }
  def asReadOnly
      : zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse.ReadOnly =
    zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse
      .wrap(buildAwsValue())
}
object DescribePermissionSetProvisioningStatusResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse =
      zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse(
        permissionSetProvisioningStatus.map(value => value.asEditable)
      )
    def permissionSetProvisioningStatus: Optional[
      zio.aws.ssoadmin.model.PermissionSetProvisioningStatus.ReadOnly
    ]
    def getPermissionSetProvisioningStatus: ZIO[
      Any,
      AwsError,
      zio.aws.ssoadmin.model.PermissionSetProvisioningStatus.ReadOnly
    ] = AwsError.unwrapOptionField(
      "permissionSetProvisioningStatus",
      permissionSetProvisioningStatus
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse
  ) extends zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse.ReadOnly {
    override val permissionSetProvisioningStatus: Optional[
      zio.aws.ssoadmin.model.PermissionSetProvisioningStatus.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.permissionSetProvisioningStatus())
      .map(value =>
        zio.aws.ssoadmin.model.PermissionSetProvisioningStatus.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse
  ): zio.aws.ssoadmin.model.DescribePermissionSetProvisioningStatusResponse.ReadOnly =
    new Wrapper(impl)
}
